shithub: freetype+ttf2subf

Download patch

ref: 7f615aef5ea990337d15c4cb3411737a0c63d583
parent: 41dbcbf6285901c9e1fcc7605cf996341af2ac3e
author: David Turner <[email protected]>
date: Mon Mar 13 06:49:20 EST 2000

renamed all outlines functions to the
FT_Outline_<action> syntax..

git/fs: mount .git/fs: mount/attach disallowed
--- a/demos/src/fttimer.c
+++ b/demos/src/fttimer.c
@@ -177,7 +177,7 @@
 #endif
 
     /* create a new outline */
-    FT_New_Outline( library,
+    FT_Outline_New( library,
                     glyph->outline.n_points, 
                     glyph->outline.n_contours, 
                     &outlines[cur_glyph] );
@@ -187,19 +187,19 @@
     if (force_low)
       glyph->outline.flags &= ~ft_outline_high_precision;
 
-    FT_Copy_Outline( &glyph->outline, &outlines[cur_glyph] );
+    FT_Outline_Copy( &glyph->outline, &outlines[cur_glyph] );
 
     /* center outline around 0 */
     {
       FT_BBox  bbox;
       
-      FT_Get_Outline_CBox( &glyph->outline, &bbox );
-      FT_Translate_Outline( &outlines[cur_glyph],
+      FT_Outline_Get_CBox( &glyph->outline, &bbox );
+      FT_Outline_Translate( &outlines[cur_glyph],
                             - ( bbox.xMax - bbox.xMin )/2,
                             - ( bbox.yMax - bbox.yMin )/2 );
     }
     /* translate it */
-    FT_Translate_Outline( &outlines[cur_glyph],
+    FT_Outline_Translate( &outlines[cur_glyph],
                           Bit.width * 32 ,
                           Bit.rows  * 32 );
     cur_glyph++;
@@ -222,7 +222,7 @@
     if (use_grays)
       return grays_raster_render( &raster, &outlines[index], &Bit );
     else
-      return FT_Get_Outline_Bitmap( library, &outlines[index], &Bit );
+      return FT_Outline_Get_Bitmap( library, &outlines[index], &Bit );
   }
 
 
@@ -458,7 +458,7 @@
 
       /* Now free all loaded outlines */
       for ( Num = 0; Num < cur_glyph; Num++ )
-        FT_Done_Outline( library, &outlines[Num] );
+        FT_Outline_Done( library, &outlines[Num] );
     }
 
     tz0 = Get_Time() - tz0;
--- a/demos/src/ftview.c
+++ b/demos/src/ftview.c
@@ -73,7 +73,7 @@
   int  graph_init = 0;
 
   int  render_mode = 1;
-  int  use_grays   = 1;
+  int  use_grays   = 0;
 
   TRaster  raster;
   
@@ -185,7 +185,7 @@
       bit3.buffer = bit_buffer;
       bit3.grays  = 128;
 
-      FT_Translate_Outline( &glyph->outline, -left, -bottom );
+      FT_Outline_Translate( &glyph->outline, -left, -bottom );
       memset( bit_buffer, 0, size );
 
       if (low_prec)
@@ -194,7 +194,7 @@
       if (use_grays & gray_render)
         error = grays_raster_render( &raster, &glyph->outline, &bit2 );
       else
-        error = FT_Get_Outline_Bitmap( library, &glyph->outline, &bit2 );
+        error = FT_Outline_Get_Bitmap( library, &glyph->outline, &bit2 );
     }
     else
     {
--- a/src/base/ftoutln.c
+++ b/src/base/ftoutln.c
@@ -32,7 +32,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Copy_Outline                                                    */
+  /*    FT_Outline_Copy                                                    */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Copies an outline into another one.  Both objects must have the    */
@@ -47,7 +47,7 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   BASE_FUNC
-  FT_Error  FT_Copy_Outline( FT_Outline*  source,
+  FT_Error  FT_Outline_Copy( FT_Outline*  source,
                              FT_Outline*  target )
   {
     FT_Int  is_owner;
@@ -79,7 +79,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Get_Outline_Bitmap                                              */
+  /*    FT_Outline_Get_Bitmap                                              */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Renders an outline within a bitmap.  The outline's image is simply */
@@ -105,7 +105,7 @@
   /*    It will use the raster correponding to the default glyph format.   */
   /*                                                                       */
   BASE_FUNC
-  FT_Error  FT_Get_Outline_Bitmap( FT_Library   library,
+  FT_Error  FT_Outline_Get_Bitmap( FT_Library   library,
                                    FT_Outline*  outline,
                                    FT_Bitmap*   map )
   {
@@ -128,7 +128,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Transform_Outline                                               */
+  /*    FT_Outline_Transform                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Applies a simple 2x2 matrix to all of an outline's points.  Useful */
@@ -142,11 +142,11 @@
   /*    Yes.                                                               */
   /*                                                                       */
   /* <Note>                                                                */
-  /*    You can use FT_Translate_Outline() if you need to translate the    */
+  /*    You can use FT_Outline_Translate() if you need to translate the    */
   /*    outline's points.                                                  */
   /*                                                                       */
   BASE_FUNC
-  void  FT_Transform_Outline( FT_Outline*  outline,
+  void  FT_Outline_Transform( FT_Outline*  outline,
                               FT_Matrix*   matrix )
   {
     FT_UShort   n;
@@ -175,7 +175,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Transform_Vector                                                */
+  /*    FT_Vector_Transform                                                */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Transforms a single vector through a 2x2 matrix.                   */
@@ -191,7 +191,7 @@
   /*    Yes.                                                               */
   /*                                                                       */
   BASE_FUNC
-  void  FT_Transform_Vector( FT_Pos*     x,
+  void  FT_Vector_Transform( FT_Pos*     x,
                              FT_Pos*     y,
                              FT_Matrix*  matrix )
   {
--- a/src/base/ftoutln.h
+++ b/src/base/ftoutln.h
@@ -6,7 +6,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Copy_Outline                                                    */
+  /*    FT_Outline_Copy                                                    */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Copies an outline into another one.  Both objects must have the    */
@@ -21,13 +21,13 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   EXPORT_DEF
-  FT_Error  FT_Copy_Outline( FT_Outline*  source,
+  FT_Error  FT_Outline_Copy( FT_Outline*  source,
                              FT_Outline*  target );
 
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Get_Outline_Bitmap                                              */
+  /*    FT_Outline_Get_Bitmap                                              */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Renders an outline within a bitmap.  The outline's image is simply */
@@ -53,7 +53,7 @@
   /*    It will use the raster correponding to the default glyph format.   */
   /*                                                                       */
   EXPORT_DEF
-  FT_Error  FT_Get_Outline_Bitmap( FT_Library   library,
+  FT_Error  FT_Outline_Get_Bitmap( FT_Library   library,
                                    FT_Outline*  outline,
                                    FT_Bitmap*   map );
 
@@ -61,7 +61,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Transform_Outline                                               */
+  /*    FT_Outline_Transform                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Applies a simple 2x2 matrix to all of an outline's points.  Useful */
@@ -75,11 +75,11 @@
   /*    Yes.                                                               */
   /*                                                                       */
   /* <Note>                                                                */
-  /*    You can use FT_Translate_Outline() if you need to translate the    */
+  /*    You can use FT_Outline_Translate() if you need to translate the    */
   /*    outline's points.                                                  */
   /*                                                                       */
   EXPORT_DEF
-  void  FT_Transform_Outline( FT_Outline*  outline,
+  void  FT_Outline_Transform( FT_Outline*  outline,
                               FT_Matrix*   matrix );
 
 
@@ -86,7 +86,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Transform_Vector                                                */
+  /*    FT_Vector_Transform                                                */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Transforms a single vector through a 2x2 matrix.                   */
@@ -102,7 +102,7 @@
   /*    Yes.                                                               */
   /*                                                                       */
   EXPORT_DEF
-  void  FT_Transform_Vector( FT_Pos*     x,
+  void  FT_Vector_Transform( FT_Pos*     x,
                              FT_Pos*     y,
                              FT_Matrix*  matrix );
 
--- a/src/base/ftraster.c
+++ b/src/base/ftraster.c
@@ -2215,7 +2215,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Decompose_Outline                                               */
+  /*    FT_Outline_Decompose                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Walks over an outline's structure to decompose it into individual  */
@@ -2237,7 +2237,7 @@
   /*    Error code.  0 means sucess.                                       */
   /*                                                                       */
   static
-  int  FT_Decompose_Outline( FT_Outline*        outline,
+  int  FT_Outline_Decompose( FT_Outline*        outline,
                              FT_Outline_Funcs*  interface,
                              void*              user )
   {
@@ -2500,7 +2500,7 @@
     ras.num_profs        = 0;
 
     /* Now decompose curve */
-    if ( FT_Decompose_Outline( outline, &interface, &ras ) )
+    if ( FT_Outline_Decompose( outline, &interface, &ras ) )
       return FAILURE;
     /* XXX: the error condition is in ras.error */
 
--- a/src/truetype/ttgload.c
+++ b/src/truetype/ttgload.c
@@ -978,7 +978,7 @@
                      -loader->pp1.x,
                      0 );
 
-    FT_Get_Outline_CBox( &glyph->outline, &bbox );
+    FT_Outline_Get_CBox( &glyph->outline, &bbox );
 
     if ( IS_HINTED(loader->load_flags) )
     {
--- a/src/truetype/ttobjs.c
+++ b/src/truetype/ttobjs.c
@@ -779,7 +779,7 @@
     FT_TRACE4(( "TT.Init_GlyphSlot: Creating outline maxp = %d, maxc = %d\n",
                 face->max_points, face->max_contours ));
 
-    return FT_New_Outline( library,
+    return FT_Outline_New( library,
                            face->max_points + 2,
                            face->max_contours,
                            &slot->outline );
@@ -803,7 +803,7 @@
     FT_Library  library = slot->face->driver->library;
 
 
-    FT_Done_Outline( library, &slot->outline );
+    FT_Outline_Done( library, &slot->outline );
     return;
   }
 
--- a/src/type1/t1gload.c
+++ b/src/type1/t1gload.c
@@ -307,7 +307,7 @@
     decoder->builder.advance      = advance;
 
     /* Finally, move the accent */
-    FT_Translate_Outline( cur, adx - asb, ady );
+    FT_Outline_Translate( cur, adx - asb, ady );
     
     (void)asb;           /* ignore this parameter */
     return T1_Err_Ok;
@@ -1510,7 +1510,7 @@
       FT_BBox           cbox;
       FT_Glyph_Metrics* metrics = &glyph->root.metrics;
 
-      FT_Get_Outline_CBox( &glyph->root.outline, &cbox );
+      FT_Outline_Get_CBox( &glyph->root.outline, &cbox );
 
       /* grid fit the bounding box if necessary */
       if (hinting)
--- a/src/type1/t1objs.c
+++ b/src/type1/t1objs.c
@@ -343,7 +343,7 @@
 #endif
 	/* the bitmaps are created on demand */
 	FREE( glyph->root.bitmap.buffer );
-    FT_Done_Outline( library, &glyph->root.outline );
+    FT_Outline_Done( library, &glyph->root.outline );
     return;
   }
 
@@ -371,13 +371,13 @@
     glyph->max_contours       = 0;
     glyph->root.bitmap.buffer = 0;
 
-    error = FT_New_Outline( library, 0, 0, &glyph->root.outline );
+    error = FT_Outline_New( library, 0, 0, &glyph->root.outline );
     if (error) return error;
 
 #ifndef T1_CONFIG_OPTION_DISABLE_HINTER
     error = T1_New_Glyph_Hinter( glyph );
     if (error)
-      FT_Done_Outline( library, &glyph->root.outline );
+      FT_Outline_Done( library, &glyph->root.outline );
 #endif
 
     return error;
--- a/src/type1z/t1gload.c
+++ b/src/type1z/t1gload.c
@@ -516,7 +516,7 @@
 
     /* Finally, move the accent */
     if (decoder->builder.load_points)
-      FT_Translate_Outline( cur, adx - asb, ady );
+      FT_Outline_Translate( cur, adx - asb, ady );
     
     (void)asb;           /* ignore this parameter */
     return T1_Err_Ok;
@@ -1248,7 +1248,7 @@
       FT_BBox           cbox;
       FT_Glyph_Metrics* metrics = &glyph->root.metrics;
 
-      FT_Get_Outline_CBox( &glyph->root.outline, &cbox );
+      FT_Outline_Get_CBox( &glyph->root.outline, &cbox );
 
       /* grid fit the bounding box if necessary */
       if (hinting)
--- a/src/type1z/t1objs.c
+++ b/src/type1z/t1objs.c
@@ -309,7 +309,7 @@
 
 	/* the bitmaps are created on demand */
 	FREE( glyph->root.bitmap.buffer );
-    FT_Done_Outline( library, &glyph->root.outline );
+    FT_Outline_Done( library, &glyph->root.outline );
     return;
   }
 
@@ -336,7 +336,7 @@
     glyph->max_contours       = 0;
     glyph->root.bitmap.buffer = 0;
 
-    return FT_New_Outline( library, 0, 0, &glyph->root.outline );
+    return FT_Outline_New( library, 0, 0, &glyph->root.outline );
   }
--- a/include/freetype.h
+++ b/include/freetype.h
@@ -2087,7 +2087,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Decompose_Outline                                               */
+  /*    FT_Outline_Decompose                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Walks over an outline's structure to decompose it into individual  */
@@ -2109,7 +2109,7 @@
   /*    Error code.  0 means sucess.                                       */
   /*                                                                       */
   EXPORT_DEF
-  int  FT_Decompose_Outline( FT_Outline*        outline,
+  int  FT_Outline_Decompose( FT_Outline*        outline,
                              FT_Outline_Funcs*  interface,
                              void*              user );
  
@@ -2117,7 +2117,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_New_Outline                                                     */
+  /*    FT_Outline_New                                                     */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Creates a new outline of a given size.                             */
@@ -2149,7 +2149,7 @@
   /*    you want to control where the objects go.                          */
   /*                                                                       */
   EXPORT_DEF
-  FT_Error  FT_New_Outline( FT_Library   library,
+  FT_Error  FT_Outline_New( FT_Library   library,
                             FT_UInt      numPoints,
                             FT_Int       numContours,
                             FT_Outline*  outline );
@@ -2158,10 +2158,10 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Done_Outline                                                    */
+  /*    FT_Outline_Done                                                    */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Destroys an outline created with FT_New_Outline().                 */
   /*                                                                       */
   /* <Input>                                                               */
   /*    library :: A handle of the library object used to allocate the     */
@@ -2185,13 +2185,13 @@
   /*    application if you want something simpler.                         */
   /*                                                                       */
   EXPORT_DEF
-  FT_Error  FT_Done_Outline( FT_Library   library,
+  FT_Error  FT_Outline_Done( FT_Library   library,
                              FT_Outline*  outline );
 
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Get_Outline_CBox                                                */
+  /*    FT_Outline_Get_CBox                                                */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Returns an outline's `control box'.  The control box encloses all  */
@@ -2218,7 +2218,7 @@
   /*    Yes.                                                               */
   /*                                                                       */
   EXPORT_DEF
-  FT_Error  FT_Get_Outline_CBox( FT_Outline*  outline,
+  FT_Error  FT_Outline_Get_CBox( FT_Outline*  outline,
                                  FT_BBox*     cbox );
 
 
@@ -2225,7 +2225,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Translate_Outline                                               */
+  /*    FT_Outline_Translate                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Applies a simple translation to the points of an outline.          */
@@ -2239,7 +2239,7 @@
   /*    Yes.                                                               */
   /*                                                                       */
   EXPORT_DEF
-  void  FT_Translate_Outline( FT_Outline*  outline,
+  void  FT_Outline_Translate( FT_Outline*  outline,
                               FT_Pos       xOffset,
                               FT_Pos       yOffset );
 
@@ -2158,10 +2158,10 @@
   /*                                                                       */
   /* <Description>                                                         */
-  /*    Destroys an outline created with FT_New_Outline().                 */
+  /*    Destroys an outline created with FT_Outline_New().                 */
   /*                                                                       */
   /* <Input>                                                               */
--- a/src/base/ftbbox.c
+++ b/src/base/ftbbox.c
@@ -45,7 +45,7 @@
   /*                                                                       */
   /* <Description>                                                         */
   /*    This function is used as a `move_to' and `line_to' emitter during  */
   /*    FT_Raster_Decompose().  It simply records the destination point in */
   /*    `user->last'.                                                      */
   /*                                                                       */
   /* <Input>                                                               */
@@ -338,7 +338,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Raster_GetBBox                                                  */
+  /*    FT_Outline_Get_BBox                                                */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Computes the exact bounding box of an outline.  This is slower     */
@@ -357,8 +357,8 @@
   /*    Error code.  0 means success.                                      */
   /*                                                                       */
   EXPORT_FUNC
-  FT_Error  FT_Raster_GetBBox( FT_Outline*  outline,
-                               FT_BBox*     abbox )
+  FT_Error  FT_Outline_Get_BBox( FT_Outline*  outline,
+                                 FT_BBox*     abbox )
   {
     FT_BBox    cbox;
     FT_BBox    bbox;
@@ -432,7 +432,7 @@
 
       user.bbox = bbox;
 
-      error = FT_Decompose_Outline( outline, &interface, &user );
+      error = FT_Outline_Decompose( outline, &interface, &user );
       if ( error )
         return error;
 
@@ -45,7 +45,7 @@
   /* <Description>                                                         */
   /*    This function is used as a `move_to' and `line_to' emitter during  */
-  /*    FT_Raster_Decompose().  It simply records the destination point in */
+  /*    FT_Outline_Decompose.  It simply records the destination point in  */
   /*    `user->last'.                                                      */
   /*                                                                       */
--- a/src/base/ftobjs.c
+++ b/src/base/ftobjs.c
@@ -2011,7 +2011,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Decompose_Outline                                               */
+  /*    FT_Outline_Decompose                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Walks over an outline's structure to decompose it into individual  */
@@ -2033,7 +2033,7 @@
   /*    Error code.  0 means sucess.                                       */
   /*                                                                       */
   EXPORT_FUNC
-  int  FT_Decompose_Outline( FT_Outline*        outline,
+  int  FT_Outline_Decompose( FT_Outline*        outline,
                              FT_Outline_Funcs*  interface,
                              void*              user )
   {
@@ -2262,7 +2262,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_New_Outline                                                     */
+  /*    FT_Outline_New                                                     */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Creates a new outline of a given size.                             */
@@ -2294,7 +2294,7 @@
   /*    you want to control where the objects go.                          */
   /*                                                                       */
   BASE_FUNC
-  FT_Error  FT_New_Outline( FT_Library   library,
+  FT_Error  FT_Outline_New( FT_Library   library,
                             FT_UInt      numPoints,
                             FT_Int       numContours,
                             FT_Outline*  outline )
@@ -2322,7 +2322,7 @@
 
   Fail:
     outline->flags |= ft_outline_owner;
-    FT_Done_Outline( library, outline );
+    FT_Outline_Done( library, outline );
 
     return error;
   }
@@ -2331,10 +2331,10 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Done_Outline                                                    */
+  /*    FT_Outline_Done                                                    */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Destroys an outline created with FT_New_Outline().                 */
   /*                                                                       */
   /* <Input>                                                               */
   /*    library :: A handle of the library object used to allocate the     */
@@ -2358,7 +2358,7 @@
   /*    application if you want something simpler.                         */
   /*                                                                       */
   BASE_FUNC
-  FT_Error  FT_Done_Outline( FT_Library   library,
+  FT_Error  FT_Outline_Done( FT_Library   library,
                              FT_Outline*  outline )
   {
     FT_Memory  memory = library->memory;
@@ -2384,7 +2384,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Get_Outline_CBox                                                */
+  /*    FT_Outline_Get_CBox                                                */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Returns an outline's `control box'.  The control box encloses all  */
@@ -2411,7 +2411,7 @@
   /*    Yes.                                                               */
   /*                                                                       */
   BASE_FUNC
-  FT_Error  FT_Get_Outline_CBox( FT_Outline*  outline,
+  FT_Error  FT_Outline_Get_CBox( FT_Outline*  outline,
                                  FT_BBox*     cbox )
   {
     FT_Pos  xMin, yMin, xMax, yMax;
@@ -2462,7 +2462,7 @@
   /*************************************************************************/
   /*                                                                       */
   /* <Function>                                                            */
-  /*    FT_Translate_Outline                                               */
+  /*    FT_Outline_Translate                                               */
   /*                                                                       */
   /* <Description>                                                         */
   /*    Applies a simple translation to the points of an outline.          */
@@ -2476,7 +2476,7 @@
   /*    Yes.                                                               */
   /*                                                                       */
   BASE_FUNC
-  void  FT_Translate_Outline( FT_Outline*  outline,
+  void  FT_Outline_Translate( FT_Outline*  outline,
                               FT_Pos       xOffset,
                               FT_Pos       yOffset )
   {
@@ -2331,10 +2331,10 @@
   /*                                                                       */
   /* <Description>                                                         */
-  /*    Destroys an outline created with FT_New_Outline().                 */
+  /*    Destroys an outline created with FT_Outline_New().                 */
   /*                                                                       */
   /* <Input>                                                               */